@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-df6969dfbc858b998ec244264fecd72a
-key: yesod_9LWeoghHzSt4CfVNvX2NMq
+id: yesod-1.4.2-c329238e8025cd02b1a2244c3dbf7a4a
+key: yesod_GSS6djoSbbGLPFgfaGKpCD
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,37 +21,37 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-9LWeoghHzSt4CfVNvX2NMq
+hs-libraries: HSyesod-1.4.2-GSS6djoSbbGLPFgfaGKpCD
 depends:
-    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
+    aeson-0.11.1.1-ac1365b396a3746ecb25074345ed217b
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
-    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
+    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
+    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
+    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
-    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
+    fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-7704b739a8ba950a4b62906c3ab56228
+    monad-logger-0.3.18-0974645d267a817a7b3484945a31ce66
     safe-0.3.9-b613242f536083d5bb04920ede356aea
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-    shakespeare-2.0.7-39cc4f42107716d9e8a539beb0a84dc6
-    streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+    shakespeare-2.0.7-4ef2bc28a9a68fc4404a3488a8a328d3
+    streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
-    wai-3.2.0-e103f0650175c07d97df46c35b6789e8
-    wai-extra-3.0.14.1-0c42224b2d6876be23597f0341613f03
-    wai-logger-2.2.4.1-174bc5cb20d0c648b67c086b95df789c
-    warp-3.2.3-65ec311029bca8d40c69f107435d220d
-    yaml-0.8.16-dde1f04caad6e58716b323c82d57d5b4
-    yesod-auth-1.4.12-4e64c62214b64b9f61de4b7b73723e55
-    yesod-core-1.4.19-76e562217b8c2dec9e581394dccca7d9
-    yesod-form-1.4.6-d7657a7d5538a6119e62f62c50053d42
-    yesod-persistent-1.4.0.3-be43da91bd3f8b1a5afded36ccce5fee
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
+    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
+    wai-extra-3.0.14.3-573d423332e41b1ef0bf196a0a0f46c9
+    wai-logger-2.2.4.1-9478a6051df96b8d5b3214f7fcca2185
+    warp-3.2.3-0fe962c9e43b4ce1b68b117c1dfdd0a0
+    yaml-0.8.16-8e3a1d884bd629b7e4f9063e0e319626
+    yesod-auth-1.4.12-6d39f9c8689d7bb14181c06ad864efcd
+    yesod-core-1.4.19-af1bfc6a6dd9bd0b41ee49e8528d9426
+    yesod-form-1.4.6-d410f0f26d14c25fe71f8e61bc7bca41
+    yesod-persistent-1.4.0.3-c0d4792363b4ae6f164db4f0ba0d02bd
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
